@@ -4,6 +4,7 @@ use Mojo::Base 'Mojo::EventEmitter';
 use Carp 'croak';
 use DBI;
 use DBD::SQLite;
+use DBD::SQLite::Constants ':database_connection_configuration_options';
 use File::Spec::Functions 'catfile';
 use File::Temp;
 use Mojo::SQLite::Database;
@@ -13,18 +14,14 @@ use SQL::Abstract;
 use URI;
 use URI::db;
 
-our $VERSION = '3.002';
+our $VERSION = '3.004';
 
-has abstract => sub { SQL::Abstract->new(name_sep => '.', quote_char => '`') };
+has abstract => sub { SQL::Abstract->new(name_sep => '.', quote_char => '"') };
 has 'auto_migrate';
 has database_class  => 'Mojo::SQLite::Database';
 has dsn             => sub { _url_from_file(shift->_tempfile)->dbi_dsn };
 has max_connections => 1;
-has migrations      => sub {
-  my $migrations = Mojo::SQLite::Migrations->new(sqlite => shift);
-  weaken $migrations->{sqlite};
-  return $migrations;
-};
+has migrations      => sub { Mojo::SQLite::Migrations->new(sqlite => shift) };
 has options => sub {
   {
     AutoCommit          => 1,
@@ -82,6 +79,8 @@ sub _dequeue {
   
   my $dbh = DBI->connect($self->dsn, undef, undef, $self->options)
     // croak "DBI connection to @{[$self->dsn]} failed: $DBI::errstr"; # RaiseError disabled
+  $dbh->sqlite_db_config(SQLITE_DBCONFIG_DQS_DDL, 0);
+  $dbh->sqlite_db_config(SQLITE_DBCONFIG_DQS_DML, 0);
   unless ($self->options->{no_wal}) {
     $dbh->do('pragma journal_mode=WAL');
     $dbh->do('pragma synchronous=NORMAL');
@@ -210,7 +209,7 @@ gracefully by holding on to them only for short amounts of time.
   get '/' => sub {
     my $c  = shift;
     my $db = $c->sqlite->db;
-    $c->render(json => $db->query('select datetime("now","localtime") as now')->hash);
+    $c->render(json => $db->query(q{select datetime('now','localtime') as now})->hash);
   };
 
   app->start;
@@ -234,9 +233,14 @@ L<DBD::SQLite/"journal_mode"> for more information.
 
   # Performed concurrently
   my $pid = fork || die $!;
-  say $sql->db->query('select datetime("now","localtime") as time')->hash->{time};
+  say $sql->db->query(q{select datetime('now','localtime') as time})->hash->{time};
   exit unless $pid;
 
+The L<double-quoted string literal misfeature
+|https://sqlite.org/quirks.html#double_quoted_string_literals_are_accepted> is
+disabled for all connections since Mojo::SQLite 3.003; use single quotes for
+string literals and double quotes for identifiers, as is normally recommended.
+
 All cached database handles will be reset automatically if a new process has
 been forked, this allows multiple processes to share the same L<Mojo::SQLite>
 object safely.
